@@ -614,12 +614,12 @@ bool FirstCipher = false;
 
   arg.erase();
 
-  while(str != "" && str[0] == ' ')
+  while(!str.isEmpty() && str[0]==' ')
     str = copy(str,1,length(str)-1);
 
   LastC = '\0';
   i = 0;
-  while (str != "" && (str[0] != ' ' || i != 0))
+  while(!str.isEmpty() && (str[0]!=' ' || i!=0))
      {
      c = str[0];
 
@@ -681,7 +681,7 @@ bool FirstCipher = false;
 		 }  
 	      }
 	 if ((c=='\\' || c=='+') &&
-	      i==0 && arg != "")
+	      i==0 && !arg.isEmpty())
 	     {
 	     str=c+str;
 	     break;
@@ -721,7 +721,7 @@ bool FirstCipher = false;
      LastC = c;
      }
 
- if(arg=="") return(LastC);
+ if(arg.isEmpty()) return(LastC);
  DeleteCurlyBraces(arg);
 
  InternalArg = arg; //Check whether arg contains any non-terminal symbol that need to be expanded
@@ -771,16 +771,16 @@ string InternalArg;
 
   arg.erase();
 
-  while(str!="" && str[0]==' ')
+  while(!str.isEmpty() && str[0]==' ')
     str=copy(str,1,length(str)-1);
 
   LastSupSub = LastC = '\0';
   ZeroPass = i = 0;
-  while(str!="")
+  while(!str.isEmpty())
      {
      c = str[0];
      if(i<=0 && !isspace(c) && !LastSupSub)
-       if(arg!="")		//argument is not empty
+       if(!arg.isEmpty())		//argument is not empty
 	{
 	if( (isspace(LastC) ||
 	      LastC=='}' || LastC==']' || LastC==')' || LastC=='"' || LastC=='\'') &&
@@ -839,13 +839,13 @@ CONTINUE:
     LastC = c;
     }
 
-while (arg != "" && arg[length(arg)-1] == ' ')
-	arg=copy(arg,0,length(arg)-1);
+while(!arg.isEmpty() && arg[length(arg)-1]==' ')
+	arg = copy(arg,0,length(arg)-1);
 if(ZeroPass==1 && arg[0]=='{' && arg[length(arg)-1]=='}')
 	arg = copy(arg,1,length(arg)-2);
 
 
-if(arg=="") return(0);
+if(arg.isEmpty()) return(0);
 
 InternalArg=arg; //Check whether arg contains any non-terminal symbol that need to be expanded
 InternalArg.ToUpper();
@@ -888,13 +888,13 @@ char c,LastC;
 
   LastC=0;
   arg.erase();
-  while(str != "" && str[length(str) - 1] == ' ')
+  while(!str.isEmpty() && str[length(str)-1] == ' ')
       {
       str = copy(str,0,length(str)-1);
       }
 
   i=0;			//Tady je chyba !!!!!!!!!!!!!!!!!!!!!
-  while (str != "") // && (str[length(str) - 1] != ' ' || i != 0))
+  while(!str.isEmpty()) // && (str[length(str) - 1] != ' ' || i != 0))
       {
       c = str[length(str) - 1];
       if (i <= 0)
@@ -922,7 +922,7 @@ char c,LastC;
 	  i++;
 	  if (i == 1)
 		{
-		if(arg=="") continue;
+		if(arg.isEmpty()) continue;
 		str+='}';	// fix the situation    "{...}arg"
 		i--;
 		break;
@@ -983,13 +983,13 @@ BYTE LastSupSub, LastCBrace;
 
   LastCBrace=LastSupSub=LastC=0;
   arg.erase();
-  while(str != "" && str[length(str) - 1] == ' ')
+  while(!str.isEmpty() && str[length(str) - 1] == ' ')
       {
       str=copy(str,0,length(str)-1);
       }
 
   i=0;			//Tady je chyba !!!!!!!!!!!!!!!!!!!!!
-  while(str != "") // && (str[length(str) - 1] != ' ' || i != 0))
+  while(!str.isEmpty()) // && (str[length(str) - 1] != ' ' || i != 0))
       {
       c = str[length(str) - 1];
       if (i <= 0)
@@ -1017,7 +1017,7 @@ BYTE LastSupSub, LastCBrace;
 	  i++;
 	  if(i==1 && !LastSupSub)
 		{
-		if(arg=="") {LastCBrace=1;continue;}	//The curly brace was temporarily omitted
+		if(arg.isEmpty()) {LastCBrace=1;continue;}	//The curly brace was temporarily omitted
 		str+='}';	// fix the situation    "{...}arg"
 		i--;
 		break;
@@ -1152,7 +1152,7 @@ void Interpret(TconvertedPass1 *cq, string & strB, string & strE,
 			case '4':Numeral=arg[4];seq++;break;
                         default: Numeral='|'; break;
 			};
-                  if(Numeral=="")
+                  if(Numeral.isEmpty())
 		   	{
 			if (cq->err != NULL)
 			    {
@@ -1180,7 +1180,7 @@ void Interpret(TconvertedPass1 *cq, string & strB, string & strE,
 			case '4':Numeral=arg[4];seq++;break;
 			default: Numeral.erase(); break;
 			};
-                  if(Numeral=="")
+                  if(Numeral.isEmpty())
 		   	{
 			if (cq->err != NULL)
 			    {
@@ -1459,7 +1459,7 @@ BYTE styles;
 		StrBeg = copy(StrBeg,0,length(StrBeg)-1);
 	//We have all equation contents in the string StrBeg at this point
 
-  if(StrBeg == "") return(false);  /*equation is empty-nothing to do*/
+  if(StrBeg.isEmpty()) return(false);  /*equation is empty-nothing to do*/
 
   StrBeg = replacesubstring(StrBeg,"\1}","\\}");              /*fix \} in WP -> \1 -> "\}"*/
   StrBeg = replacesubstring(StrBeg,"\1{","\\{");              /*fix \} in WP -> \1 -> "\}"*/
