@@ -61,7 +61,7 @@ public:
   virtual ~SaveEpsJob() {err=NULL;}
 };
 
-  /// Save EPS image from different thread.
+	/// Save EPS image from different thread.
   void SavePictureEPS_MT(const string &FILE_NAME, Image &IMAGE_OBJ, FILE *ERR_STREAM, Percentor*PPERCENTOR)
   {
     RunJob(new SaveEpsJob(IMAGE_OBJ, FILE_NAME, ERR_STREAM));    
@@ -69,7 +69,7 @@ public:
 
 #else
 
- /// Save imageas EPS immediatelly.
+	/// Save image as EPS immediatelly, no multithread supported.
  inline void SavePictureEPS_MT(const string &FILE_NAME, Image &IMAGE_OBJ, FILE *ERR_STREAM, Percentor*PPERCENTOR) 
  {
   if(SavePictureEPS(FILE_NAME(),IMAGE_OBJ) < 0)
@@ -433,7 +433,7 @@ CpTranslator *PsNativeSym = GetTranslator("internalTOsymbol");
   if(cq5->ConvertCpg==NULL)
     cq5->ConvertCpg = GetTranslator("wp5TOinternal");
 
-  cq5->ActualPos=cq->ActualPos+21;
+  cq5->ActualPos = cq->ActualPos+21;
   ldblk+=cq5->ActualPos;
   fseek(cq5->wpd,cq5->ActualPos,SEEK_SET);
   cq5->flag = Nothing;
@@ -682,7 +682,7 @@ CpTranslator *PsNativeSym = GetTranslator("internalTOsymbol");
 
 
 /** Load array of points word packed. */
-float *LoadPoints(TconvertedPass1 *cq, int n, FloatBBox &bbx, AbstractTransformXY *TRx, bool Precision)
+float *LoadPoints(TconvertedPass1 *cq, int n, FloatBBox &bbx, AbstractTransformXY *TRx, bool Precision, float LineWidth)
 {
 #ifdef DEBUG
   fprintf(cq->log,"\n#LoadPoints(%d) ",n);fflush(cq->log);
@@ -693,6 +693,9 @@ float *Points, *p;
   p = Points = (float*)calloc(2*n,sizeof(*Points));
   if(Points==NULL) return(NULL);
 
+  if(LineWidth<=0) LineWidth=0;
+              else LineWidth /= 2;
+
   float x, y;  
   while(n-->0)
     {
@@ -707,18 +710,18 @@ float *Points, *p;
       else
         {
         SDWORD d;
-	Rd_dword(cq->wpd, (DWORD *)&d);
+	Rd_dword(cq->wpd, (DWORD*)&d);
 	x = d / 65536.0;
-	Rd_dword(cq->wpd,(DWORD *)&d);
+	Rd_dword(cq->wpd,(DWORD*)&d);
 	y = d / 65536.0;
         }
 
       if(TRx) TRx->ApplyTransform(x,y);
 
-      if(x<bbx.MinX) bbx.MinX=x;
-      if(x>bbx.MaxX) bbx.MaxX=x;
-      if(y<bbx.MinY) bbx.MinY=y;
-      if(y>bbx.MaxY) bbx.MaxY=y;
+      if(x-LineWidth<bbx.MinX) bbx.MinX=x-LineWidth;
+      if(x+LineWidth>bbx.MaxX) bbx.MaxX=x+LineWidth;
+      if(y-LineWidth<bbx.MinY) bbx.MinY=y-LineWidth;
+      if(y+LineWidth>bbx.MaxY) bbx.MaxY=y+LineWidth;
 
       *p++ = x;
       *p++ = y;
@@ -832,10 +835,10 @@ public:
 
 void vecResizeCTM::ApplyTransform(float &x, float &y) const
 {
-const float NewX = 
+const float Val = 
      ScaleX*x + SkewX*y  + TranslateX;
- y = SkewY*x  + ScaleY*y + TranslateY;
- x = NewX;
+ y = SkewY*x  + y*ScaleY + TranslateY;
+ x = Val;
 }
 
 
@@ -899,6 +902,7 @@ Raster2DAbstract *Raster = NULL;
 long ldblk;
 vecResizeCTM TRx;
 
+  TRx.Precision = StartWPG.PosSizePrecision;
   switch(Rec2.Type)
     {
     case 0x1:LoadWPG2Start(cq->wpd,StartWPG);
@@ -909,7 +913,7 @@ vecResizeCTM TRx;
 		}
 		  // Start extensions must be read separatelly.
 	     cq->recursion++;
-             while(cq->ActualPos<ResourceEnd && Rec2.Extension-->0)
+             while(cq->ActualPos<ResourceEnd && Rec2.Extension-->0)  // Consider all extensions to be nested.
 	       {	       
 	       WPG2Record Rec2b;
                if(NewObjectPos!=ftell(cq->wpd))
@@ -1147,14 +1151,17 @@ vecResizeCTM TRx;
 		  break;
 		  }
     case 0x15:{strcpy(cq->ObjType,"Polyline");
+		//  CrackObject(cq,NewObjectPos);
 		  float *Points;
                   WPG_records WPG;
 
-		  TRx.LoadWPG2Flags(cq->wpd,StartWPG.PosSizePrecision);
+		  TRx.LoadWPG2Flags(cq->wpd);
 
 		  Rd_word(cq->wpd,&WPG.Curve.Count);
+	          //if(StartWPG.PosSizePrecision==1) fseek(cq->wpd,2,SEEK_CUR);
+
 		  FixPolySize(cq, &WPG.Curve.Count, (StartWPG.PosSizePrecision==0)?Rec2.RecordLength:(Rec2.RecordLength/2)); //insufficient fix -sizeof(CTM)!!!
-		  Points = LoadPoints(cq, WPG.Curve.Count, bbx, &TRx, StartWPG.PosSizePrecision>0);
+		  Points = LoadPoints(cq, WPG.Curve.Count, bbx, &TRx, StartWPG.PosSizePrecision>0, PSS.LineWidth);
 		  if(Points==NULL) break;
 
 		  if(TRx.Flags & WPG2_Transform::WPG2_FILL)	//check Fill flag
@@ -1185,7 +1192,7 @@ vecResizeCTM TRx;
 		  float *Points;
 		  WPG_records WPG;
 
-		  TRx.LoadWPG2Flags(cq->wpd,StartWPG.PosSizePrecision);
+		  TRx.LoadWPG2Flags(cq->wpd);
 			//!!RotAngle Ignored!!!
 		  Rd_word(cq->wpd,&WPG.Curve.Count);
 		  WPG.Curve.Count *= 3;
@@ -1202,7 +1209,7 @@ vecResizeCTM TRx;
 		  }
     case 0x18:{   WPG_records WPG;
 	          strcpy(cq->ObjType,"Rectangle");
-		  TRx.LoadWPG2Flags(cq->wpd,StartWPG.PosSizePrecision);
+		  TRx.LoadWPG2Flags(cq->wpd);
 		  ImgSts.RotAngle = TRx.RotAngle;
 
 		  LoadWPG2Rectangle(cq->wpd,WPG._2Rect);
@@ -1219,7 +1226,7 @@ vecResizeCTM TRx;
 		  WPG_records WPG;
 	          strcpy(cq->ObjType,"Arc");
                   //CrackObject(cq,NewObject);
-		  TRx.LoadWPG2Flags(cq->wpd,StartWPG.PosSizePrecision);
+		  TRx.LoadWPG2Flags(cq->wpd);
 		  LoadWPG2Arc(cq->wpd,WPG._2Arc);
 
                   float Sx = WPG._2Arc.Sx;
@@ -1263,11 +1270,12 @@ vecResizeCTM TRx;
 		  }
 
     case 0x1A:strcpy(cq->ObjType,"!Compound Polygon");break;
+
     case 0x1B:{
 	      WPG_records WPG;
 	      strcpy(cq->ObjType,"Bitmap position");
 	      //CrackObject(cq,NewObject);//!!!!
-	      TRx.LoadWPG2Flags(cq->wpd,StartWPG.PosSizePrecision);	      
+	      TRx.LoadWPG2Flags(cq->wpd);
               //printf("\n Rot angle = %f    ", RotAngle);
               
               float Sx, Sy;
@@ -1322,7 +1330,7 @@ vecResizeCTM TRx;
     case 0x1C:{
               WPG_records WPG;
 	      strcpy(cq->ObjType,"Text Line");
-	      TRx.LoadWPG2Flags(cq->wpd,StartWPG.PosSizePrecision);
+	      TRx.LoadWPG2Flags(cq->wpd);
 	      ImgSts.RotAngle = TRx.RotAngle;
 
 	      LoadWPG2TextLine(cq->wpd,WPG._2TxtLine);
@@ -1334,7 +1342,7 @@ vecResizeCTM TRx;
     case 0x1D:{
 	      WPG_records WPG;
 	      strcpy(cq->ObjType,"Text Block");
-              TRx.LoadWPG2Flags(cq->wpd,StartWPG.PosSizePrecision);
+              TRx.LoadWPG2Flags(cq->wpd);
 	      ImgSts.RotAngle = TRx.RotAngle;
               if(StartWPG.PosSizePrecision==0)
                 {
@@ -1357,16 +1365,90 @@ vecResizeCTM TRx;
               break;
     case 0x1E:strcpy(cq->ObjType,"!Text Path");break;
     case 0x1F:strcpy(cq->ObjType,"!Chart");break;
-    case 0x20:strcpy(cq->ObjType,"!Group");break;
-    case 0x21:{strcpy(cq->ObjType,"!Object Capsule");break;
+    case 0x20:{
+	      FloatBBox bbxIn;
+	      bbxIn.MinX=65537; bbxIn.MaxX=-1; bbxIn.MinY=65537; bbxIn.MaxY=-1;
+	      TRx.LoadWPG2Flags(cq->wpd);
+	      VectorList VectListIn;
+	      cq->recursion++;	      
+              while(cq->ActualPos<ResourceEnd && Rec2.Extension-->0)  // Consider all extensions to be nested.
+	        {	       
+	        WPG2Record Rec2b;
+                if(NewObjectPos!=ftell(cq->wpd))
+	            fseek(cq->wpd,NewObjectPos,SEEK_SET);
+                cq->ActualPos = NewObjectPos;
+
+	        Rec2b.Class = fgetc(cq->wpd);
+	        Rec2b.Type = fgetc(cq->wpd);		
+	       
+	        Rd_WP_DWORD(cq->wpd,&Rec2b.Extension);
+	        Rd_WP_DWORD(cq->wpd,&Rec2b.RecordLength);
+	        cq->ActualPos = ftell(cq->wpd);
+	        NewObjectPos = cq->ActualPos + Rec2b.RecordLength;
+	       
+                ProcessWPG2Token(cq, Rec2b, StartWPG, Img, Palette, PSData, PSS, EmImg, NewObjectPos, ResourceEnd, CurrImg,
+				  ImgSts, bbxIn, VectListIn);	        
+	        }
+	      cq->recursion--;
+	      if(VectListIn.VectorObjects > 0)
+                {
+	        TRx.ApplyTransform(bbxIn.MinX,bbxIn.MinY);	      
+	        UpdateBBox(bbx,0, bbxIn.MinX,bbxIn.MinY,0,0);
+	        TRx.ApplyTransform(bbxIn.MaxX,bbxIn.MaxY);
+	        UpdateBBox(bbx,0, bbxIn.MaxX,bbxIn.MaxY,0,0);
+	        TRx.TranslateX *= WPGu2PSu(1);		// Bounding box is in PS units.
+	        TRx.TranslateY *= WPGu2PSu(1);
+	        VectListIn.Transform(TRx);
+	        VectList.Append(VectListIn);
+                }	      
+	      strcpy(cq->ObjType,"Group");
+	      break;
+	      }
+    case 0x21:{	      
+	      FloatBBox bbxIn;
+	      bbxIn.MinX=65537; bbxIn.MaxX=-1; bbxIn.MinY=65537; bbxIn.MaxY=-1;
+	      TRx.LoadWPG2Flags(cq->wpd);
+	      VectorList VectListIn;
+	      cq->recursion++;	      
+              while(cq->ActualPos<ResourceEnd && Rec2.Extension-->0)  // Consider all extensions to be nested.
+	        {	       
+	        WPG2Record Rec2b;
+                if(NewObjectPos!=ftell(cq->wpd))
+	            fseek(cq->wpd,NewObjectPos,SEEK_SET);
+                cq->ActualPos = NewObjectPos;
+
+	        Rec2b.Class = fgetc(cq->wpd);
+	        Rec2b.Type = fgetc(cq->wpd);		
+	       
+	        Rd_WP_DWORD(cq->wpd,&Rec2b.Extension);
+	        Rd_WP_DWORD(cq->wpd,&Rec2b.RecordLength);
+	        cq->ActualPos = ftell(cq->wpd);
+	        NewObjectPos = cq->ActualPos + Rec2b.RecordLength;
+	       
+                ProcessWPG2Token(cq, Rec2b, StartWPG, Img, Palette, PSData, PSS, EmImg, NewObjectPos, ResourceEnd, CurrImg,
+				  ImgSts, bbxIn, VectListIn);	        
+	        }
+	      cq->recursion--;
+	      if(VectListIn.VectorObjects > 0)
+                {
+	        TRx.ApplyTransform(bbxIn.MinX,bbxIn.MinY);	      
+	        UpdateBBox(bbx,0, bbxIn.MinX,bbxIn.MinY,0,0);
+	        TRx.ApplyTransform(bbxIn.MaxX,bbxIn.MaxY);
+	        UpdateBBox(bbx,0, bbxIn.MaxX,bbxIn.MaxY,0,0);
+	        TRx.TranslateX *= WPGu2PSu(1);		// Bounding box is in PS units.
+	        TRx.TranslateY *= WPGu2PSu(1);
+	        VectListIn.Transform(TRx);
+	        VectList.Append(VectListIn);
+                }
+	      strcpy(cq->ObjType,"Object Capsule");break;
 	      }
     case 0x22:strcpy(cq->ObjType,"!Font Settings");break;
     case 0x23:strcpy(cq->ObjType,"!Line Cap Definition");break;
     case 0x24:strcpy(cq->ObjType,"!Line Join Definition");break;
     case 0x25:{strcpy(cq->ObjType,"Pen Fore Color");
-	      PSS.LineColor.Red=fgetc(cq->wpd);
-	      PSS.LineColor.Green=fgetc(cq->wpd);
-	      PSS.LineColor.Blue=fgetc(cq->wpd);
+	      PSS.LineColor.Red = fgetc(cq->wpd);
+	      PSS.LineColor.Green = fgetc(cq->wpd);
+	      PSS.LineColor.Blue = fgetc(cq->wpd);
 	      //PSS.LineColor.Transparency=fgetc(cq->wpd);
 	      PSS.dirty |= PSS_LineColor;
 	      break;
@@ -1459,7 +1541,7 @@ vecResizeCTM TRx;
 		PSS.FillColor.Green = G >> 8;
 		PSS.FillColor.Blue = B >> 8;
 		PSS.FillTransparency = A >> 8;
-                sprintf(cq->ObjType,"DP Brush Fore Color n:%d (%X %X %X; %X)",
+                sprintf(cq->ObjType,"DP Brush Fore Color n:%d (%2X %2X %2X; %2X)",
 		    (int)BrushColors, R, G, B, A);
                 }                
               else
@@ -1579,7 +1661,7 @@ vecResizeCTM TRx;
     fprintf(cq->log,"\n%*s{GRtyp#%X;len:%lXh;%s}", cq->recursion*2, "",
             (int)Rec2.Type, (long)Rec2.RecordLength, cq->ObjType);
 		    //fprintf(cq->log,"MaxY= %2.2f",MaxY);
-    fprintf(cq->log," Pos= %lX", (long)cq->ActualPos);
+    fprintf(cq->log," Pos=%lXh", (long)cq->ActualPos);
     }
   if(*cq->ObjType=='!' || *cq->ObjType=='?')
 	{UnknownObjects++;*cq->ObjType=0;}
@@ -1667,7 +1749,7 @@ TryWPG1:
 	Rec.RecType=fgetc(cq->wpd);
 	Rd_WP_DWORD(cq->wpd,&Rec.RecordLength);
 	if(feof(cq->wpd)) break;
-	cq->ActualPos=ftell(cq->wpd);
+	cq->ActualPos = ftell(cq->wpd);
 	DWORD NewObject = cq->ActualPos+Rec.RecordLength;
 
 	NumFormat=0;
@@ -2031,7 +2113,7 @@ LoadRaster:	      if(CurrImg->Raster!=NULL)
 	  fprintf(cq->log,"\n%*s{GRtyp#%Xh;len:%lXh;%s}",cq->recursion * 2, "",
 		     (int)Rec2.Type, (long)Rec2.RecordLength, cq->ObjType);
 		    //fprintf(cq->log,"MaxY= %2.2f",MaxY);
-	  fprintf(cq->log," Pos= %lX", (long)cq->ActualPos);
+	  fprintf(cq->log," Pos=%lXh", (long)cq->ActualPos);
 	  }
 	cq->ActualPos = (NewObject+1) & ~1;
         fseek(cq->wpd,cq->ActualPos,SEEK_SET);
