@@ -13,7 +13,7 @@ void StoreText2PS(string & PSData, string & Text, PS_State *PSS, WORD RotAngle,
 
 class TconvertedPass1;
 class AbstractTransformXY;
-float *LoadPoints(TconvertedPass1 *cq, int n, FloatBBox &bbx, AbstractTransformXY *TRx=NULL,bool Precision=false);
+float *LoadPoints(TconvertedPass1 *cq, int n, FloatBBox &bbx, AbstractTransformXY *TRx=NULL,bool Precision=false,float LineWidth=0);
 
 
 void AddCharacterToContainer(TextContainer *pTextCont, WORD WchI, const CpTranslator *PsNativeCP, const CpTranslator *PsNativeSym, 
