@@ -1068,6 +1068,25 @@ void VectorList::AddObject(VectorObject *NewObj)
 }
 
 
+void VectorList::Append(VectorList &VectList)
+{
+  if(FirstObject==NULL)
+  {
+    FirstObject = VectList.FirstObject;
+    LastObject = VectList.LastObject;
+    VectorObjects = VectList.VectorObjects;
+  }
+  else
+  {
+    LastObject->NextObject = VectList.FirstObject;
+    LastObject = VectList.LastObject;
+    VectorObjects += VectList.VectorObjects;
+  }
+  VectList.FirstObject = VectList.LastObject = NULL;
+  VectList.VectorObjects = 0;    
+}
+
+
 void VectorList::Export2EPS(FILE *F, PS_State *PSS) const
 {
 VectorObject *IterObject = FirstObject;
@@ -1117,6 +1136,7 @@ TextContainer::TextContainer()
   TextObjects = 0;
   FontOrientation = 0;
   RotCenterX = RotCenterY = 0;
+  TextAllign = 0;
 }
 
 
@@ -1142,7 +1162,7 @@ TextContainer::~TextContainer()
 /// Append show only when needed. The intent is not to emit "() show". Too much empty
 /// strings only bloat image. Of course that "(\()" is a string containing one character.
 /// @param[in,out]	str	String that needs either cleanup or adding \show.
-void AppendShow(string &str)
+void AppendShow(string &str, unsigned char HorizontalPos)
 {
   int len = length(str);
   if(len==0) return;
@@ -1158,6 +1178,11 @@ void AppendShow(string &str)
         }
       }
     }
+  if((HorizontalPos & 6) == 6)
+    {
+    str += "\ndup stringwidth pop -2 div"
+	   "\n0 rmoveto";
+    }
   str += "\nshow";
 }
 
@@ -1196,7 +1221,7 @@ const bool TextRotated = fabs(NormAngleDEG(FontOrientation)) > 0.01;
         FixPsAccent(Text[i]->contents,"\\\"{","(\\310)");	// umlaut
         FixPsAccent2(Text[i]->contents,"\\accent39","( \\47)"); //insert space before apostrophe \\47
         
-        if(i>0) AppendShow(str);
+        if(i>0) AppendShow(str,TextAllign);
 	
         if(PSS!=NULL)
         {
@@ -1261,7 +1286,7 @@ const bool TextRotated = fabs(NormAngleDEG(FontOrientation)) > 0.01;
         }
       }      
     }
-    AppendShow(str);
+    AppendShow(str,TextAllign);
     if(TextRotated)
     {    
       str += "\ngrestore";
@@ -1342,7 +1367,7 @@ TextObject *pTobj;
   pTobj->contents = contents;
   
   pTobj->size = PSS.FontSize;
-    //pTobj->Weight = Weight;  
+  //pTobj->Weight = Weight;  
   memcpy(&pTobj->TextColor,&PSS.TextColor,sizeof(RGB_Record));  
 }
 
