@@ -223,6 +223,7 @@ public:
 
   void AddObject(VectorObject *NewObj);
   virtual void Transform(const AbstractTransformXY &Tx);
+  void Append(VectorList &VectList);
 
   VectorObject *FirstObject;
   VectorObject *LastObject;
@@ -346,6 +347,7 @@ public:
   float PosX, PosY;		///< Tex start point.
   float FontOrientation;	///< Font rotation [deg]
   float RotCenterX, RotCenterY;
+  BYTE TextAllign;
 
   TextContainer();
   virtual ~TextContainer();  
