@@ -274,7 +274,7 @@ void AttrOff(TconvertedPass1 *cq, char attr_num)
 string s;
 
  _AttrOff(cq->attr,attr_num,s);
- if(s!="") fputs(s(),cq->strip);
+ if(!s.isEmpty()) fputs(s(),cq->strip);
 
  if(attr_num==Heb_Font && cq->Font==FONT_HEBREW)
    {
@@ -347,7 +347,7 @@ void Attr_OFF(TconvertedPass1 *cq, unsigned char b)
   if ((b==7) && ((LaTeX_Version & 0xFF00) < 0x300))  goto RejectAttr;
 
   _AttrOff(cq->attr,b & 0xF,s);
-  if(s!="") fputs(s(),cq->strip);
+  if(!s.isEmpty()) fputs(s(),cq->strip);
 
 RejectAttr:
   sprintf(cq->ObjType, "Attr %d Off",(int)b);
@@ -405,7 +405,7 @@ const char *ch;
  * @return 	LaTeX string that causes selected attributes to close. */
 temp_string Attributes2String(DWORD Attributes)
 {
-temp_string TexAttrib;
+string TexAttrib;
 			//Solve attributes for columns
  if(Attributes &  1) {TexAttrib+="\\LARGE";goto SizeOK;}
  if(Attributes &  2) {TexAttrib+="\\Large";goto SizeOK;}
@@ -429,7 +429,7 @@ SizeOK:
  if(Attributes & 32768)TexAttrib+="\\sc";
     //65536 blink
     //131072 reverse video
-return TexAttrib;
+return temp_string(TexAttrib);
 }
 
 
@@ -1063,7 +1063,7 @@ void EndSection(TconvertedPass1 *cq, signed char WP)
 
   if(OptimizeSection && cq->envir!='B') _AttrOff(cq->attr,b,s);
 				   else _AttrOff(cq->attr,Last_com_section+1,s);
-  if(s!="") fputs(s(),cq->strip);
+  if(!s.isEmpty()) fputs(s(),cq->strip);
 }
 
 
@@ -1650,7 +1650,7 @@ void Page_number_position(TconvertedPass1 *cq, unsigned char WP)
 	    fseek(cq->wpd, 14L + 2L*IDs, SEEK_CUR);
 	    Rd_dword(cq->wpd, &Attributes);
 	    PgNumAttrS = Attributes2String(Attributes);
-	    if(PgNumAttrS!="") PgNumAttr=PgNumAttrS();
+	    if(!PgNumAttrS.isEmpty()) PgNumAttr=PgNumAttrS();
 	    fseek(cq->wpd, -9L, SEEK_CUR);
 	    }
 					    /* + old information */
@@ -1888,7 +1888,7 @@ Found:
 	i=1;
 	}
     if(FontName != NULL)
-      if(TexFontName != "")
+      if(!TexFontName.isEmpty())
 	{
 	fprintf(cq->strip,"\\fontshape{%s}",TexFontName());
 	i|=2;
