@@ -658,7 +658,7 @@ char BoxType;
 
 	      attr.InitAttr();
 	      i = OptimizeFormulaStr(this,StrBeg);
-	      if(StrBeg=="") goto LEqEmpty;
+	      if(StrBeg.isEmpty()) goto LEqEmpty;
 	      if(i!=0 && Box.AnchorType==2) StrBeg+='\n';
 
 	      attr = OldAttr;	      
@@ -1422,7 +1422,7 @@ void TconvertedPass1_WP5::Overstrike(DWORD end_of_code)
       }
 
   AttrFit(attr,OldAttr,s);
-  if(s!="") fputs(s(),strip);
+  if(!s.isEmpty()) fputs(s(),strip);
 
   recursion--;
   strcpy(ObjType, "Overstrike");
@@ -1557,7 +1557,7 @@ FAIL:	strcpy(ObjType, "!Table Start"); return;
     {
     TexAttrib = Attributes2String(Atbl[i].attribute); //Solve attributes for columns
 
-    if(TexAttrib != "")
+    if(!TexAttrib.isEmpty())
 	{
 	fprintf(strip,"@{%s}",TexAttrib());
 	}
