@@ -125,7 +125,7 @@ int UseMemStream=0;
 bool OptimizeSection;
 signed char Verbosing;	  ///< <=-1 no errors, <=0 no warnings, 1 normal, >1 verbosive
 #ifdef _REENTRANT
-short JobCount = -1;
+short Job4Run = -1;
 #endif
 bool TexChars;
 bool ExtendedCheck, FixSpaces;
@@ -427,7 +427,7 @@ string s;
   while(CharNo<MaxChar)
 	{
 	if( (chr=fgetc(text)) == EOF) goto NoAccent;
-	chr=toupper(chr);
+	chr = toupper(chr);
 	CharNo++;
 	switch(Status)
 		{
@@ -441,7 +441,7 @@ string s;
 		case 3:if(chr=='R') {Status=4;break;}
 		       goto NoAccent;
 		case 4:if(isspace(chr)) break;
-		       Status=5;
+		       Status = 5;
 		case 5:if(chr=='>')
 			    {
 			    fseek(text,0,SEEK_SET);
@@ -449,7 +449,7 @@ string s;
 				 return(1);	//Accent succesfully detected
 			    else return(0);
 			    }
-		       s+=chr;
+		       s += chr;
 		       break;
 		default:printf(_("Error: State automat failed at state %d\n"),Status);
 			Status=0;
@@ -1766,7 +1766,7 @@ int p;
 #ifdef _REENTRANT
 	if(!strcmp(name, "jobs")||!strcmp(name, "Jobs")) /*-no-columns*/
 		{
-		JobCount = 0;
+		Job4Run = 0;
 		continue;
 		}
 #endif
