@@ -623,13 +623,22 @@ char str[20];
      }
    }
 #if defined(POINTER_SIZE)
- if(8*sizeof(void*)!=POINTER_SIZE)
+ if(8*sizeof(void*) != POINTER_SIZE)
  {
    Heading();
-   fprintf(err,_("\nFatal: Compillation has been optimised for pointer size 32bits, pointer size is %ubits!"), 8*sizeof(void*));
+   fprintf(err,_("\nFatal: Compillation has been optimised for pointer size %ubits, pointer size is %ubits!"), POINTER_SIZE, (unsigned)sizeof(void*)*8);
    AskUser();
  }
 #endif
+#ifdef LO_ENDIAN
+  int i=1;
+  if(*((unsigned char *)&i) != 1)
+  {
+    Heading();
+    fprintf(err,_("\nFatal: Compillation has been optimised for LO_ENDIAN that does not belong to this system!"));
+    AskUser();
+  }
+#endif
 }
 
 
@@ -664,7 +673,7 @@ TconvertedPass1 *cqPass1;
   log_filename = "default.log";
 #endif
 //  clrscr();
-
+  
 #ifdef __gettext__
   InitGettext("wp2latex");
 #endif /* __gettext__ */
@@ -687,7 +696,7 @@ TconvertedPass1 *cqPass1;
     StyleOpCl = StyleOpCl2;
 
 #ifdef _REENTRANT
-  InitJobs(JobCount);
+  InitJobs(Job4Run);
 #endif
 
   if((wpd = fopen(wpd_filename, "rb")) == NULL)
