@@ -4,8 +4,8 @@
  * modul:       wp2latex.h                                                    *
  * description: Contains global definitions and prototypes                    *
  ******************************************************************************/
-#ifndef __Wp2Latex__
-#define __Wp2Latex__
+#ifndef __Wp2LaTex__
+#define __Wp2LaTex__
 
 
 #ifndef __TYPES_INCLUDED
@@ -17,8 +17,8 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"3.100"
-#define VersionDate	"2 Oct 2021"  /* day (space) month (space) full year */
+#define VersionWP2L	"3.101"
+#define VersionDate	"1 Nov 2021"  /* day (space) month (space) full year */
 
 #ifndef false
  #define  false          0
@@ -28,10 +28,13 @@
 #endif
 
 /* Constants for a flag InputPS */
-#define IMG_InputPS	0
-#define IMG_graphicx	2
-#define IMG_epsfig	4
-#define IMG_graphics	8
+typedef enum
+{
+    IMG_InputPS	=	0,
+    IMG_graphicx =	2,
+    IMG_epsfig =	4,
+    IMG_graphics =	8
+} EflagsInputPS;
 
 extern unsigned short OutCodePage, WPcharset;
 extern bool Index, Interactive, NFSS, TABs, twoside, ExactFnNumbers, CPStyles,
@@ -44,7 +47,7 @@ extern int LaTeX_Version;
 extern signed char Verbosing;
 extern bool TexChars,ExtendedCheck,OptimizeSection,FixSpaces;
 #ifdef _REENTRANT
-extern short JobCount;
+extern short Job4Run;
 #endif
 
 typedef struct			/* Auto detection structure for file formats */
@@ -393,9 +396,10 @@ char *GetSomeImgName(const char *Ext=NULL);
  #ifdef __cplusplus
   extern "C" {
  #endif
- void InitGettext(const char *GtxtDomain);
+ void InitGettext(const char *GtxtDomain); 
  void CheckGettext(const char *PROG_NAME, const char *GtxtDomain);
  //char *gettext__ (const char *__msgid);
+ void FixConsole2UTF8(void);
  #ifdef __cplusplus
   }
  #endif
